
# Type: exon to transcript relationship_subject




URI: [biolink:exon_to_transcript_relationship_subject](https://w3id.org/biolink/vocab/exon_to_transcript_relationship_subject)


## Domain and Range

[ExonToTranscriptRelationship](ExonToTranscriptRelationship.md) ->  <sub>REQ</sub> [Exon](Exon.md)

## Parents

 *  is_a: [sequence feature relationship➞subject](sequence_feature_relationship_subject.md)

## Children


## Used by

 * [ExonToTranscriptRelationship](ExonToTranscriptRelationship.md)
